@@ -77,7 +77,7 @@ BackupProfileInfoWidget::BackupProfileInfoWidget( QWidget* parent, const char* n
 
     connect( setSelection, SIGNAL( clicked() )                 , this, SLOT( slotSetSelection() ) );
     connect( getSelection, SIGNAL( clicked() )                 , this, SLOT( slotGetSelection() ) );
-    connect( _name       , SIGNAL( textChanged( const char* ) ), this, SLOT( slotTextChanged( const char* ) ) );
+    connect( _name       , SIGNAL( textChanged( const QString & ) ), this, SLOT( slotTextChanged( const QString & ) ) );
     connect( _profile    , SIGNAL( sigSomethingChanged() )     , this, SLOT( slotSomethingChanged() ) );
     connect( _apply      , SIGNAL( clicked() )                 , this, SLOT( slotApply() ) );
 }
@@ -101,15 +101,15 @@ void BackupProfileInfoWidget::setBackupProfile( BackupProfile* backupProfile )
 
 bool BackupProfileInfoWidget::isModified()
 {
-    if ( strcmp( _backupProfile->getName(), _name->text() ) ) {
+    if ( _backupProfile->getName() != _name->text() ) {
         return TRUE;
     }
 
-    if ( strcmp( _profile->getArchiveName(), _backupProfile->getArchiveName() ) ) {
+    if ( _profile->getArchiveName() != _backupProfile->getArchiveName() ) {
         return TRUE;
     }
 
-    if ( strcmp( _profile->getWorkingDirectory(), _backupProfile->getWorkingDirectory() ) ) {
+    if ( _profile->getWorkingDirectory() != _backupProfile->getWorkingDirectory() ) {
         return TRUE;
     }
 
@@ -117,15 +117,17 @@ bool BackupProfileInfoWidget::isModified()
         return TRUE;
     }
 
-    QStrListIterator i( _profile->getAbsoluteFiles() );
-    QStrListIterator j( _backupProfile->getAbsoluteFiles() );
-    for ( ; i.current(); ++i ) {
-        for ( j.toFirst(); j.current(); ++j ) {
-            if ( !strcmp( i.current(), j.current() ) ) {
+    QStringList list1 = _profile->getAbsoluteFiles();
+    QStringList list2 = _backupProfile->getAbsoluteFiles();
+    QStringList::Iterator i = list1.begin();
+    QStringList::Iterator j = list2.begin();
+    for ( ; i != list1.end(); ++i ) {
+        for ( ; j != list2.end(); ++j ) {
+            if ( *i == *j ) {
                 break;
             }
         }
-        if ( !j.current() ) {
+        if ( j == list2.end() ) {
             // Could not find i.current() in j => lists are not equal.
             return TRUE;
         }
@@ -139,7 +141,7 @@ bool BackupProfileInfoWidget::isModified()
         return TRUE;
     }
 
-    if ( strcmp( _profile->getSnapshotFile(), _backupProfile->getSnapshotFile() ) ) {
+    if ( _profile->getSnapshotFile() != _backupProfile->getSnapshotFile() ) {
         return TRUE;
     }
 
@@ -150,7 +152,7 @@ bool BackupProfileInfoWidget::isModified()
     return FALSE;
 }
 
-void BackupProfileInfoWidget::slotTextChanged( const char* )
+void BackupProfileInfoWidget::slotTextChanged( const QString & )
 {
     if ( !_backupProfile ) {
         return;
@@ -195,7 +197,7 @@ void BackupProfileInfoWidget::slotSetSelection()
 
 void BackupProfileInfoWidget::slotGetSelection()
 {
-    QStrList files;
+    QStringList files;
     KDat::getInstance()->getBackupFiles( files );
     _profile->setAbsoluteFiles( files );
 }
