@@ -61,12 +61,12 @@ BackupProfileManager* BackupProfileManager::instance()
     return _instance;
 }
 
-const QStrList& BackupProfileManager::getBackupProfileNames()
+const QStringList& BackupProfileManager::getBackupProfileNames()
 {
     return _backupProfileNames;
 }
 
-BackupProfile* BackupProfileManager::findBackupProfile( const char* name )
+BackupProfile* BackupProfileManager::findBackupProfile( const QString & name )
 {
     BackupProfile* backupProfile = _backupProfiles[ name ];
 
