@@ -20,7 +20,7 @@
 
 #include "File.h"
 
-File::File( File* parent, int size, int mtime, int startRecord, int endRecord, const char* name )
+File::File( File* parent, int size, int mtime, int startRecord, int endRecord, const QString & name )
         : _stubbed( FALSE ),
           _name( name ),
           _parent( parent )
@@ -134,7 +134,7 @@ void File::write( FILE* fptr )
     // File name (4 bytes + n chars).
     int ival = getName().length();
     fwrite( &ival, sizeof( ival ), 1, fptr );
-    fwrite( getName().data(), sizeof( char ), ival, fptr );
+    fwrite( getName().ascii(), sizeof( char ), ival, fptr );
 
     // File size (4 bytes).
     ival = getSize();
