@@ -46,12 +46,12 @@ Tape::Tape()
     time_t tm = time( NULL );
     _ctime = tm;
     _mtime = tm;
-    _id.sprintf( "%s:%d", buffer, tm );
+    _id.sprintf("%s:%d", buffer, tm);
 
     write();
 }
 
-Tape::Tape( const char* id )
+Tape::Tape( const char * id )
         : _stubbed( TRUE ),
           _id( id ),
           _ctime( -1 ),
@@ -103,7 +103,7 @@ void Tape::format()
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID length failed." ), i18n("OK") );
         return;
     }
-    if ( TapeDrive::instance()->write( _id.data(), iv ) < iv ) {
+    if ( TapeDrive::instance()->write( _id, iv ) < iv ) {
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Format Failed" ), i18n( "Writing tape ID failed." ), i18n("OK") );
         return;
     }
@@ -191,7 +191,7 @@ void Tape::read()
         default:
         {
             QString msg;
-            msg.sprintf( i18n( "The tape index file format is version %d.  The index cannot be read by this version of KDat.  Perhaps the tape index file was created by a newer version of KDat?" ), version );
+            msg = QString::fromUtf8(QCString().sprintf( i18n( "The tape index file format is version %d.  The index cannot be read by this version of KDat.  Perhaps the tape index file was created by a newer version of KDat?" ).utf8(), version ) );
             QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), msg, i18n("OK") );
         }
     }
@@ -235,7 +235,7 @@ void Tape::write()
     fwrite( &_size , sizeof( _size  ), 1, _fptr );
     char buf[4096];
     memset( buf, 0, 4096 );
-    memcpy( buf, _name.data(), _name.length() > 4095 ? 4095 : _name.length() );
+    memcpy( buf, _name.ascii(), _name.length() > 4095 ? 4095 : _name.length() );
     fwrite( buf, sizeof( char ), 4096, _fptr );
     int ival = _children.count();
     fwrite( &ival, sizeof( ival ), 1, _fptr );
@@ -304,7 +304,7 @@ const QList<Archive>& Tape::getChildren()
     return _children;
 }
 
-void Tape::setName( const char* name )
+void Tape::setName( const QString & name )
 {
     read();
 
@@ -321,7 +321,7 @@ void Tape::setName( const char* name )
     fgets( buf, 4096, _fptr );
     fseek( _fptr, 12, SEEK_CUR );
     memset( buf, 0, 4096 );
-    memcpy( buf, _name.data(), _name.length() > 4095 ? 4095 : _name.length() );
+    memcpy( buf, _name.ascii(), _name.length() > 4095 ? 4095 : _name.length() );
     fwrite( buf, sizeof( char ), 4096, _fptr );
     fflush( _fptr );
 
@@ -471,9 +471,9 @@ void Tape::readVersion1Index( FILE* fptr )
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
-    QString tapeID = buf;
+    QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
-    if ( tapeID != _id ) {
+    if ( tapeID !=_id ) {
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
         return;
     }
@@ -618,7 +618,7 @@ void Tape::readVersion2Index( FILE* fptr )
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
-    QString tapeID = buf;
+    QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
@@ -680,7 +680,7 @@ void Tape::readVersion3Index( FILE* fptr )
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
-    QString tapeID = buf;
+    QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
@@ -723,7 +723,7 @@ void Tape::readVersion4Index( FILE* fptr )
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Reading tape ID failed." ), i18n("OK") );
         return;
     }
-    QString tapeID = buf;
+    QCString tapeID = buf;
     tapeID.truncate( tapeID.length() - 1 );
     if ( tapeID != _id ) {
         QMessageBox::warning( KDat::getInstance(), i18n( "KDat: Index File Error" ), i18n( "Tape ID on tape does not match tape ID in index file." ), i18n("OK") );
