@@ -43,7 +43,7 @@ TapeManager::TapeManager()
         it++)
     {
         QString fn = *it;
-        // Convert to outdated QStrList :-)
+        // Convert to outdated QStringList :-)
         _tapeIDs.append( QFile::encodeName(fn) );
     }
 }
@@ -63,17 +63,17 @@ TapeManager* TapeManager::instance()
     return _instance;
 }
 
-const QStrList& TapeManager::getTapeIDs()
+const QStringList& TapeManager::getTapeIDs()
 {
     return _tapeIDs;
 }
 
-Tape* TapeManager::findTape( const char* id )
+Tape* TapeManager::findTape( const QString & id )
 {
     Tape* tape = _tapes[ id ];
 
     if ( !tape ) {
-        tape = new Tape( id );
+        tape = new Tape( id.ascii() );
         _tapes.insert( tape->getID(), tape );
     }
 
