@@ -190,7 +190,7 @@ public slots:
      * @param data   An array of data bytes.
      * @param length The length of the data array.
      */
-    void slotData( const QString & data, int length );
+    void slotData( const char * data, int length );
 signals:
     /**
      * This signal is emitted whenever a file entry is parsed from the archive.
