@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-#include <qstrlist.h>
+#include <qstringlist.h>
 #include <kglobal.h>
 #include <klocale.h>
 
@@ -28,42 +28,37 @@ QString Util::bytesToString( uint bytes )
 
 QString Util::kbytesToString( uint kbytes )
 {
-    QString str;
-
-    str.setNum( kbytes );
-    str += "k";
-    for ( int i = str.length() - 4; i > 0; i -= 3 ) {
-        str.insert( i, ',' );
-    }
-
-    return str;
+    return KGlobal::locale()->formatNumber(kbytes, 0) + 'k';
 }
 
-QString Util::longestCommonPath( const QStrList& files )
+QString Util::longestCommonPath( const QStringList& files )
 {
-    QStrListIterator i( files );
+    QStringList filesTmp = files;
+    QStringList::Iterator i = filesTmp.begin();
 
-    uint minLen = strlen( i.toFirst() );
-    for ( ; i.current(); ++i ) {
-        if ( minLen > strlen( i.current() ) ) {
-            minLen = strlen( i.current() );
+    uint minLen = (*i).length();
+    for ( ; i != filesTmp.end(); ++i ) {
+        if ( minLen > (*i).length() ) {
+            minLen = (*i).length();
         }
     }
     uint j;
     for ( j = 0; j < minLen; j++ ) {
-        const char* first = i.toFirst();
-        for ( ; i.current(); ++i ) {
-            if ( strncmp( first, i.current(), j ) ) {
+        i = filesTmp.begin();
+        QString first = *i;
+        for ( ; i != filesTmp.end(); ++i ) {
+            if ( first.left(j) != (*i).left(j) ) {
                 // Prefixes are NOT the same.
                 break;
             }
         }
-        if ( i.current() ) {
+        if ( i != filesTmp.end() ) {
             // The common prefix is 0 to j-1, inclusive.
             break;
         }
     }
-    QString prefix = i.toFirst();
+    i = filesTmp.begin();
+    QString prefix = *i;
     int idx = prefix.findRev( '/', j );
     if ( idx > -1 ) {
         prefix = prefix.left( prefix.findRev( '/', j ) );
