@@ -40,7 +40,7 @@ public:
     /**
      * Find the longest common path prefix for a list of files.
      */
-    static QString longestCommonPath( const QStrList& files );
+    static QString longestCommonPath( const QStringList& files );
 };
 
 #endif
