@@ -1,6 +1,6 @@
 /*
- * $Revision: 1.3 $
- * $Date: 1999/03/10 22:17:29 $
+ * $Revision: 1.4 $
+ * $Date: 2000/08/05 19:45:51 $
  * 
  * KTreeView class interface
  * 
@@ -423,13 +423,13 @@ public:
      * children. A KTreeViewItem is created for which the delete-children
      * flag is set to true.
      */
-    void appendChildItem(const char* theText, const QPixmap& thePixmap,
+    void appendChildItem(const QString & theText, const QPixmap& thePixmap,
 		      int index);
 
     /**
      * Same as above except that the parent item is specified by a path.
      */
-    void appendChildItem(const char* theText, const QPixmap& thePixmap,
+    void appendChildItem(const QString & theText, const QPixmap& thePixmap,
 		      const KPath& thePath); 
 
     /**
@@ -476,7 +476,7 @@ public:
 	enabled. If changing only the text or pixmap, set the other parameter
 	to 0.
 	*/
-  void changeItem(const char *newText, 
+  void changeItem(const QString & newText, 
 				  const QPixmap *newPixmap, 
 				  int index);
 
@@ -484,7 +484,7 @@ public:
 	Same as above function, except item to change is specified by a path
 	through the tree.
 	*/
-  void changeItem(const char *newText,
+  void changeItem(const QString & newText,
 				  const QPixmap *newPixmap,
 				  const KPath& thePath);
 
@@ -573,7 +573,7 @@ public:
      * delete-children flag is set to true. Returns true if the item has
      * been successfully inserted in the tree, otherwise false.
      */
-    bool insertItem(const char* theText, const QPixmap& thePixmap,
+    bool insertItem(const QString & theText, const QPixmap& thePixmap,
 		    int row = -1, bool prefix = true);
 
     /**
@@ -581,7 +581,7 @@ public:
      * insert position. If there is no item at the specified path, the item
      * is simply appended to the tree at the topmost level.
      */
-    bool insertItem(const char* theText, const QPixmap& thePixmap,
+    bool insertItem(const QString & theText, const QPixmap& thePixmap,
 		    const KPath& thePath, bool prefix = true);
 
     /**
@@ -795,7 +795,7 @@ protected:
     virtual int cellHeight(int row);
     virtual int cellWidth(int col);
     void changeItem(KTreeViewItem* toChange,
-		    int itemRow, const char* newText,
+		    int itemRow, const QString & newText,
 		    const QPixmap* newPixmap);
     /**
      * Collapses the specified subtree and updates the display. subRoot
