@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: cache.h,v 1.1.1.1 1999/02/11 04:18:40 toivo Exp $ 
+//      $Id: cache.h,v 1.4 2000/07/14 15:58:15 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -26,13 +26,25 @@ public:
   QString base;
   QString location;
   QString cacheFile;
+  QString option;
+  bool    subdirs;
 
-  cacheObj(QString Pbase, QString Plocation, QString PcacheFile);
+  cacheObj(QString Pbase, QString Plocation, QString PcacheFile, QString Poption = QString::null, bool Psubdirs = FALSE);
   ~cacheObj();
 
   static QString PDir();
+  // return path of kpackage cache directory
+
   static QString CDir();
-  static  int newDCache(const char *url, QString fn, QString *fname);
+  // return path of kpackage directory cache
+
+  static  int newDCache(QString url, QString fn, QString &fname);
+  // Checks directory cache
+  //  -1  Cann't get cache file name
+  //   0  Cache file exists
+  //   1  Cache file doesn't exit
+  // fname return  file name
+
   static  void rmDCache(QString fn);
 
   static void clearDCache();
