@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////
-//      $Id: debInterface.h,v 1.9 2000/07/14 15:58:15 toivo Exp $ 
+//      $Id: debInterface.h,v 1.15 2001/01/14 16:44:21 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -26,44 +26,55 @@ class packageInfo;
 class updateLoc;
 class cacheObj;
 
+#define AVAIL          "/var/lib/dpkg/available"
+#define STATUS          "/var/lib/dpkg/status"
+
+#define INFODIR         "/var/lib/dpkg/info/"
+
+
 class DEB: public pkgInterface
 {
   Q_OBJECT
 
 public:
-  DEB();
+  DEB(QString remote);
   ~DEB();
   
-  bool isType(char *buf, const QString &fname);
-  void listPackages(QList<packageInfo> *pki);
-  param *initinstallOptions();
-  param *inituninstallOptions();
-  packageInfo *getPackageInfo(char mode, const QString &name, const QString &version);
-  QStringList *getFileList(packageInfo *p);
+  virtual bool isType(char *buf, const QString &fname);
 
-  void listInstalledPackages(QList<packageInfo> *pki);
+  virtual packageInfo *getPackageInfo(char mode, const QString &name,
+			      const QString &version);
+  virtual QStringList getFileList(packageInfo *p);
 
-  QString FindFile(const QString &name);
-  bool parseName(QString name, QString *n, QString *v);
+  virtual void listInstalledPackages(QList<packageInfo> *pki);
+
+  virtual QString FindFile(const QString &name);
+  virtual bool parseName(QString name, QString *n, QString *v);
+
+  virtual packageInfo* collectInfo(QStringList &inp);
+
+  QString uninstall(int uninstallFlags, QList<packageInfo> *p,
+				  bool &test);
+  QString install(int installFlags, QList<packageInfo> *p,
+				  bool &test);
+  QString doInstall(int installFlags, QString packs, bool &test);
 
 public slots:
   void setLocation();
   void setAvail(LcacheObj *);
 
-private:
+protected:
   packageInfo *getIPackageInfo(const QString &name);
   packageInfo *getUPackageInfo(const QString &name);
 
-  packageInfo* collectInfo(QStringList &inp);
   void listPackList(QList<packageInfo> *pki,
 		    const QString &fname, cacheObj *cp);
-  int dpkgChange(int del);
-
-  int doUninstall(int installFlags, QString packs);
-  int doInstall(int installFlags, QString packs);
 
   void distPackages(QList<packageInfo> *pki, cacheObj *cp);
   void listUnIPackages(QList<packageInfo> *pki, LcacheObj *pCache);
+
+  QStringList getIFileList(packageInfo *p);
+  QStringList getUFileList(QString fn);
 };
 
 #endif
