@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: findf.cpp,v 1.14 2000/08/28 20:05:54 waba Exp $ 
+//      $Id: findf.cpp,v 1.16 2001/01/23 18:48:06 matz Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -10,11 +10,13 @@
 #include "managementWidget.h"
 #include "pkgInterface.h"
 #include "findf.h"
+#include "options.h"
 #include <klocale.h>
 #include <qlineedit.h>
 #include <qdragobject.h>
 
 extern pkgInterface *kpinterface[];
+extern Opts *opts;
 
 FindF::FindF(QWidget *parent)
     : QDialog(parent, 0,FALSE){
@@ -81,7 +83,7 @@ void FindF::doFind(const QString &str)
   tab->clear();
 
   for (i = 0; i < kpinterfaceN; i++) {
-    if (kpinterface[i]) {
+    if (kpinterface[i] && opts->handlePackage[i]) {
       s = kpinterface[i]->FindFile(str);
 
       if (s.length() > 0) {
@@ -104,10 +106,10 @@ void FindF::doFind(const QString &str)
 	}
       }
     }
+  }
 
-    if (!cnt) {
-      new QListViewItem(tab, "", i18n("--Nothing found--"));
-    }
+  if (!cnt) {
+    new QListViewItem(tab, "", i18n("--Nothing found--"));
   }
 }
 
@@ -123,7 +125,8 @@ void FindF::search(QListViewItem *item)
 {
   int p;
   QString s = item->text(1);
-    
+  kdDebug() << "searchF=" << s << "\n";
+
   p = s.find(',');
   if (p > 0) {
     s.truncate(p);
