@@ -1,5 +1,5 @@
 /////////////////////////////////////////////////////////////////////////
-// $Id: managementWidget.h,v 1.15 2000/08/25 13:29:26 toivo Exp $	
+// $Id: managementWidget.h,v 1.16 2001/02/13 16:28:50 toivo Exp $	
 // File  : managementWidget.h
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
@@ -94,6 +94,9 @@ public:
   void sweep() ;
   // sweep package tree adjusting visibility
 
+  void doChangePackage(packageInfo *p);
+  // emit change package
+
 protected:
   void resizeEvent(QResizeEvent *re);
   // This is called when the widget is resized
