@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: procbuf.cpp,v 1.15 2000/09/13 14:42:14 toivo Exp $ 
+//      $Id: procbuf.cpp,v 1.18 2000/12/13 14:14:44 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -26,6 +26,8 @@ void Modal::terminate()
 procbuf::procbuf()
 {
   m = NULL;
+  tm = new QTimer(this);
+  connect(tm, SIGNAL(timeout()), this, SLOT(slotTimeout()));
 }
 
 procbuf::~procbuf()
@@ -52,9 +54,15 @@ void procbuf::slotReadInfo(KProcess *, char *buffer, int buflen)
    char last;
 
    last = buffer[buflen - 1];
-   buffer[buflen - 1] = 0;
+   buffer[buflen - 1] = 0; 
+
    buf += buffer;
    buf += last;
+
+   if (timed) {
+     timed =  FALSE;
+     tm->stop();
+   }
 }
 
 void procbuf::slotExited(KProcess *)
@@ -62,12 +70,30 @@ void procbuf::slotExited(KProcess *)
   if (m) {
     m->terminate();
   }
+  if (timed) {
+    timed =  FALSE;
+    tm->stop();
+  }
 }
 
-int procbuf::start (const QString & msg, bool errorDlg )
+void procbuf::slotTimeout()
 {
+  if (m) {
+    m->terminate();
+  }
+  kdDebug() << "TTT\n";
+}
+
+int procbuf::start (QString  msg, bool errorDlg,
+		    int timeout, QString timeMsg )
+{
+  if (timeout) {
+    tm->start(timeout*1000, TRUE);   
+    timed = true;
+  }
+
   if (!proc->start(!msg.isNull() ? KProcess::NotifyOnExit : KProcess::Block,
-		   KProcess::AllOutput)) {
+		   KProcess::All)) {
     if (errorDlg) {
       KpMsgE(i18n("Kprocess Failure"),TRUE);
     }
@@ -85,15 +111,20 @@ int procbuf::start (const QString & msg, bool errorDlg )
 	    << " dialog=" << errorDlg 
 	    << " normal=" << proc->normalExit()
 	    << " exit=" << proc->exitStatus() << endl;
-
-  if (!proc->normalExit() || proc->exitStatus()) {
-    if (errorDlg) {
-      KpMsg("Error",i18n("Kprocess error:%1").arg(buf), TRUE);
-    }
+  if (timed) {
+    kdDebug() << "timeout..................\n";
+    KpMsg("Error",i18n("Timeout: %1").arg(timeMsg), TRUE);
     delete proc; proc = 0;
     return 0;
+  } else {
+    if (!proc->normalExit() || proc->exitStatus()) {
+      if (errorDlg) {
+	KpMsg("Error",i18n("Kprocess error:%1").arg(buf), TRUE);
+      }
+      delete proc; proc = 0;
+      return 0;
+    }
   }
-
   delete proc;  proc = 0;
   return 1;
 }
