@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: procbuf.h,v 1.3 2000/08/05 19:45:51 bieker Exp $ 
+//      $Id: procbuf.h,v 1.4 2000/12/13 14:14:44 toivo Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -7,6 +7,7 @@
 #include <kprocess.h>
 #include <qdialog.h> 
 #include <qobject.h> 
+#include <qtimer.h>
 
 #ifndef PROCBUF
 #define PROCBUF
@@ -20,20 +21,25 @@ public:
 
 class procbuf: public QObject
 {
-Q_OBJECT;
+  Q_OBJECT;
 
 public:
-   procbuf();
-   ~procbuf();
-   void setup(QString);
-   QString buf;
-   KProcess *proc; 
-   Modal *m;
-   QString command;
-   int start(const QString & msg, bool errorDlg = TRUE);
+  procbuf();
+  ~procbuf();
+  void setup(QString);
+  int start(QString  msg, bool errorDlg = TRUE,
+	    int timeout=0, QString timeMsg = "");
+
+  QString buf;
+  KProcess *proc; 
+  Modal *m;
+  QString command;
+  bool timed;
+  QTimer *tm;
 
 public slots:
   void slotReadInfo(KProcess *, char *, int);
   void slotExited(KProcess *);
+  void slotTimeout();
 };
 #endif
