@@ -1,9 +1,12 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: rpmutils.h,v 1.2 1999/07/13 15:30:29 toivo Exp $ 
+//      $Id: rpmutils.h,v 1.2.4.1 2001/03/08 20:52:49 reiher Exp $ 
 //
 #include "../config.h"
 #include <string.h>
 
+/* stupid RPM headers! */
+#include <sys/types.h>
+typedef __off64_t off64_t;
 #include <rpm/rpmlib.h>
 
 int findPackageByLabel(rpmdb db, const char *arg, dbiIndexSet *matches);
