@@ -1,5 +1,5 @@
 //////////////////////////////////////////////////////////////         
-//      $Id: updateLoc.h,v 1.6 2000/05/02 15:01:39 toivo Exp $ 
+//      $Id: updateLoc.h,v 1.15 2000/09/01 20:19:46 waba Exp $ 
 //
 // Author: Toivo Pedaste
 //
@@ -27,7 +27,6 @@
 #include <kapp.h>
 #include <kmenubar.h>
 //#include <kmsgbox.h>
-#include <ktmainwindow.h> 
 #include <kbuttonbox.h> 
 #include <kfiledialog.h> 
 
@@ -35,6 +34,7 @@ class pkgInterface;
 class updateLoc;
 class cacheObj;
 class LcacheObj;
+class KComboBox;
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
@@ -44,18 +44,20 @@ class dpanel : public QWidget
 
 public:
   dpanel(updateLoc *upd, QString Pfilter, QWidget *parent,
-	 bool buse = TRUE, QString name  = 0 );
+	 bool buse = TRUE, const char * name  = 0, bool bsubdirs = TRUE );
   ~dpanel();
 
 
-  KFileDialog* getFileDialog(const char* captiontext, bool dir);
   QString getText();
-  void setText(const char *s);
+  void setText(QString s);
   bool getUse();
   void setUse(int n);
+  bool getSubdirs();
+  void setSubdirs(int n);
 
 private:
 
+  QCheckBox *psubdirs;
   QCheckBox *puse;
   QHBoxLayout* pack;
   QLineEdit *pent;
@@ -79,8 +81,8 @@ class updateLoc : public QDialog
 public:
 
   updateLoc (QWidget *p, int panelNumber, int numberLines, pkgInterface *inter,
-	     QString msg, QString iname, QString filter,
-	     QString lmsg, QString bmsg = 0);
+	     QString options, QString iname, QString filter,
+	     QString lmsg, QString bmsg = 0, bool subdirs = FALSE);
   ~updateLoc(); 
 
   void restore();
@@ -97,7 +99,7 @@ public:
 private:
 
   QString interName;
-  QString packL, packU, availB;
+  QString packL, packU, packS, packC, availB;
   int panNumber;
 
   int wdth;
@@ -111,11 +113,10 @@ private:
   QGroupBox *fbase;
   QVBoxLayout* vbase;
 
-  static const int PNUM = 8;
+  static const int PNUM = 40;
   int numLines;
-  QGroupBox *floc;
-  QVBoxLayout* vloc;
   dpanel *dp[PNUM];
+  KComboBox *combo[PNUM];
 
   QVBoxLayout* vl;
   QVBoxLayout* vtop, *vf;
@@ -130,14 +131,22 @@ class Locations : public QDialog
   Q_OBJECT
 
 public:
-Locations( const char *msg);
+Locations( QString msg);
 void dLocations(int numberDirs,  int numberLines,
 		     pkgInterface *inter, QString label,
-		     QString iname, QString filter, QString dirMsg);
+		     QString iname, QString filter, QString dirMsg,
+		     bool subdirs=TRUE );
+
 void pLocations(int numberDirs,  int numberLines,
-		     pkgInterface *inter, const  QString label,
+		     pkgInterface *inter, QString label,
 		     QString iname, QString filter,
-		     QString packMsg, QString baseMsg = 0);
+		     QString packMsg, QString baseMsg = 0,
+		     bool subdirs=FALSE);
+
+void cLocations(int numberDirs, int numberLines,
+		     pkgInterface *inter, QString label, QString iname,
+		     QString filter, 
+		QString packMsg, QString baseMsg, QString options);
 
   // bmsg indicates the panel has a base entry
 ~Locations();
@@ -145,7 +154,7 @@ void restore();
 
 QTabDialog *tab;
 int numPanels;
-static const int PANNUM = 12;
+static const int PANNUM = 10;
 updateLoc *pn[PANNUM];
 
 public slots:
