@@ -29,21 +29,27 @@
 #include <kglobal.h>
 #include <kstddirs.h>
 
+#include <kdebug.h>
+
+
 #include <X11/Xlib.h>
 
 #include "pcidevice.h"
 
 
 PCIDevice::PCIDevice(uint bus, uint slot, uint func, uint vendorid, 
-		     uint deviceid, baseclass bclass, 
+		     uint deviceid, uint subvendorid, uint subdeviceid, baseclass bclass, 
 		     pciclass pclass) : _vendorname(""),
 		     			_devicename(""),
 		     			_bus(bus),
 		     			_slot(slot),
 					_func(func),
 					_vendorid(vendorid),
-					_deviceid(deviceid)
+					_deviceid(deviceid),
+					_subvendorid(subvendorid),
+					_subdeviceid(subdeviceid)
 {
+
   _pciclass = (pciclass) ((((uint) bclass) << 8)+((uint) pclass));
   
   lookupData();
@@ -191,6 +197,7 @@ void  PCIDevice::lookupData()
   char           buffer[256];
   FILE           *fhd;
   uint           vid, did;
+  uint			 subidpass = 0;
   
   if ((fhd = fopen(QFile::encodeName(idfile), "r")))
   {
@@ -200,51 +207,86 @@ void  PCIDevice::lookupData()
       
       if (entry.length() > 4)					// Line contains data
       {
-        entry = entry.simplifyWhiteSpace();
+        //entry = entry.simplifyWhiteSpace();
 	
-        if ((entry.at(0) != ' ') && (entry.at(0) != '#'))  	// Line contains vendor information
+        if ((entry.at(0) != '\t') && (entry.at(0) != '#'))  	// Line contains vendor information
 	{
 	  sscanf(buffer, "%04x", &vid);
 	  
+	  if (vid == _subvendorid && _subvendorid != 0)
+	  {
+		_vendorname = entry.right(entry.length()-4);
+        _vendorname = _vendorname.stripWhiteSpace();
+		if( subidpass == 1 ) break;
+		subidpass = 1;
+	  }
 	  if (vid == _vendorid)					// Vendor matches
 	  {
-            _vendorname = entry.right(entry.length()-4);
-	    _vendorname = _vendorname.stripWhiteSpace();
-	    
+		if( _vendorname.isEmpty()) {
+        	_vendorname = entry.right(entry.length()-4);
+	    	_vendorname = _vendorname.stripWhiteSpace();
+	    }
 	    while (fgets(buffer, sizeof(buffer), fhd))
-            {
+        {
 	      entry = QString(buffer);
               
 	      if (entry.length() > 4)			      	// Line contains data
-              {
+          {
  
-                if (entry.at(0) == '\t')			// Line contains device information
-                {
-                  entry = entry.simplifyWhiteSpace();
-	          entry = entry.stripWhiteSpace();
+            if (entry.at(0) == '\t')			// Line contains device information
+          	{
+                entry = entry.simplifyWhiteSpace();
+		        entry = entry.stripWhiteSpace();
 		  
-		  sscanf(entry.ascii(), "%04x", &did);
+		  		sscanf(entry.ascii(), "%04x", &did);
 		  
-		  if (did == _deviceid)				// Device matches
-		  {
+		  		if (did == _deviceid)				// Device matches
+		  		{
                     _devicename = entry.right(entry.length()-4);
-	            _devicename = _devicename.stripWhiteSpace();
-		  
-		    break;
-		  }
-		} 
-		else 
-		{
-		  if ((entry.at(0) != ' ') && (entry.at(0) != '#')) 
-		  {
-		    _devicename = i18n("Unknown device");
-		    break;
-		  }
-		}		 
+	            	_devicename = _devicename.stripWhiteSpace();
+		 			// Look if there is a sub entry for the device and the sub 
+					// vendor id
+					 
+	    			while (fgets(buffer, sizeof(buffer), fhd))
+        			{
+	      				entry = QString(buffer);
+              
+	      				if (entry.length() > 4)			      	// Line contains data
+          				{
+ 
+            				if ((entry.at(0) == '\t') && (entry.at(1) == '\t'))			// Line contains device information
+          					{
+                				entry = entry.simplifyWhiteSpace();
+		        				entry = entry.stripWhiteSpace();
+
+		  						sscanf(entry.ascii(), "%04x %04x", &vid, &did);
+
+		  						if ((did == _subdeviceid) && (vid == _subvendorid))				// Device matches
+		  						{
+                    				_devicename = entry.right(entry.length()-10);
+	            					_devicename = _devicename.stripWhiteSpace();
+									break;
+								}
+								
+							} else {
+								break;
+							}
+						}
+					}
+		    		break;
+		  		}
+			} else {
+		  		if ((entry.at(0) != '\t') && (entry.at(0) != '#')) 
+		  		{
+		    		_devicename = i18n("Unknown device");
+		    		break;
+		  		}
+			}		 
 	      }	      
 	    }
 	    
-	    break;
+	    if(subidpass == 1) break;
+		subidpass = 1;
 	  }
 	}
       }
@@ -257,47 +299,46 @@ void  PCIDevice::lookupData()
 
 XServer  *PCIDevice::serverInfo()
 {
-  Display  *display;
   XServer  *xserver;
-  int      release;
   QString  name, relstr, vendor;
-  QString  line;
-  char     monthname[16];
-  int      day, year;
-  int      month;
   QDate    date;
   
+  Display  *display;
   if (!(display = XOpenDisplay(0))) return 0L;
 
-  release = VendorRelease(display);
+  int release = VendorRelease(display);
   
   if ((vendor = ServerVendor(display)).contains("XFree86", true))
   {
-    // Server is XFree86, so we can rely on some things
-    
     name = "XFree86";
     relstr.sprintf("%i.%i.%i", release/100, (release%100)/10, release%10);
-  
-    QFile  xerr(QDir::homeDirPath()+"/.X.err");
-    
-    if (xerr.exists())
-    {
-      if (xerr.open(IO_ReadOnly))
-      {
-        QTextStream  s(&xerr);
-        
-        for (int i = 0; i < 5; i++) line = s.readLine(); 
 
-        sscanf(line.ascii(), "Release Date: %s %i %i", monthname, &day, &year);
+    // Server is XFree86, so we can rely on some things
+    FILE     *fhd;
+    if ((fhd = popen("X -showconfig 2>&1", "r")))
+    {
+      QTextStream  s(fhd, IO_ReadOnly);
         
-        for (month = 1; month < 13; month++) 
-          if (date.monthName(month) == QString(monthname).left(3)) break;
+      for (int i = 0; (!s.eof()) && (i < 5); i++)
+      {
+        QString line = s.readLine(); 
+
+        if ( !line.isEmpty() && line.startsWith("Release Date:") )
+        {
+          int day, year;
+          int month;
+          char monthname[16];
+          sscanf(line.ascii(), "Release Date: %s %i %i", monthname, &day, &year);
+        
+          for (month = 1; month < 13; month++) 
+            if (date.monthName(month) == QString(monthname).left(3)) break;
           
-        date = QDate(year, month, day);
-      
-        xerr.close();
-      } 
-    } 
+          date = QDate(year, month, day);
+          break;
+        }
+      }
+      pclose(fhd);
+    }
   }
   
   xserver = new XServer(name, relstr, vendor, date);
