@@ -81,12 +81,12 @@ PCIDevice  *PCIScanner::device()
   uint                 irq;
   ulong                memadd[6], romadd;
   uint                 bus, slot, func;
-  uint                 vendorid, deviceid, iorange;
+  uint                 vendorid, deviceid, iorange, subvendorid, subdeviceid;
   Device::baseclass    baseclass;
   PCIDevice::pciclass  pciclass;
   PCIDevice            *pcidev;
   int                  i;
- kdDebug() << "PCIScanner::device()" << endl; 
+ kdDebug() << "PCIScanner::device()" << endl;
   if (fgets(buffer, 256, _pcifhd))
   {
     sscanf(buffer, "%x%lx%x%lx%lx%lx%lx%lx%lx%lx", &devfn,
@@ -99,19 +99,22 @@ PCIDevice  *PCIScanner::device()
   						   &memadd[4],
   						   &memadd[5],
   						   &romadd);
- 
+   
     bus      = devfn >> 8U;
     slot     = (devfn >> 3) & 0x1f;
     func     = devfn & 0x07;
     vendorid = device >> 16;
     deviceid = device & 0xffff;
- 
+
     if (readPCIHeader(bus, slot, func, buffer, 64))
     {
       baseclass = (Device::baseclass)   ((uchar) buffer[11]);
       pciclass  = (PCIDevice::pciclass) ((uchar) buffer[10]);
- 
-      pcidev    = new PCIDevice(bus, slot, func, vendorid, deviceid, baseclass, pciclass);
+	  
+	  subvendorid 	= buffer[44] + ( (uchar) buffer[45] * 256);
+	  subdeviceid 	= buffer[46] + ( (uchar) buffer[47] * 256);
+	
+      pcidev    = new PCIDevice(bus, slot, func, vendorid, deviceid, subvendorid, subdeviceid, baseclass, pciclass);
      
       if (irq) pcidev->addResource(new Interrupt(irq));
      
