@@ -1,12 +1,9 @@
 #ifndef _KU_GLOBALS_H_
-#define _KU_GLOBALS_H_ "$Id: globals.h,v 1.12.2.5 1999/06/29 06:41:41 garbanzo Exp $"
+#define _KU_GLOBALS_H_
 
 #define _KU_VERSION "1.0"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
+#include "../config.h"
 #include <kconfig.h>
 #include "kerror.h"
 
@@ -33,7 +30,7 @@ extern int is_shadow;
   #define SKELDIR "/etc/skel"
   #define SKEL_FILE_PREFIX ""
 #else
-  #ifdef __FreeBSD__
+  #if	defined(__FreeBSD__) || defined(__bsdi__)
     #undef _KU_SHADOW
     #include <pwd.h>
     #include <paths.h>
