@@ -10,7 +10,6 @@
 #include <kconfig.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
-#include <ktmainwindow.h>
 #include <kaboutdata.h>
 
 #include "kglobal_.h"
@@ -53,8 +52,9 @@ int main(int argc, char **argv) {
   
   KAboutData aboutData("kuser", I18N_NOOP("KUser"),
     _KU_VERSION, description, KAboutData::License_GPL, 
-    i18n("(c) 1997-2000, Denis Perchine"));
-  aboutData.addAuthor(i18n("Denis Perchine"), 0, "dyp@perchine.com");
+    "(c) 1997-2000, Denis Perchine");
+  aboutData.addAuthor("Denis Perchine", I18N_NOOP("kuser author"),
+    "dyp@perchine.com", "http://www.perchine.com/dyp/");
   KCmdLineArgs::init(argc, argv, &aboutData);
   mainWidget *mw = NULL;
 
