@@ -1,8 +1,8 @@
 #include "globals.h"
 
-#include <qmessagebox.h>
 #include <qlayout.h>
 
+#include <kmessagebox.h>
 #include <kbuttonbox.h>
 
 #include "usernamedlg.h"
@@ -43,8 +43,8 @@ usernamedlg::usernamedlg(KUser *auser, QWidget* parent, const char* name)
   bbox->addStretch(1);
 
   // the default buttons  
-  pbOk = bbox->addButton(i18n("OK"));
-  pbCancel = bbox->addButton(i18n("Cancel"));
+  pbOk = bbox->addButton(i18n("&OK"));
+  pbCancel = bbox->addButton(i18n("&Cancel"));
   pbOk->setDefault(TRUE);
   
   // establish callbacks
@@ -68,21 +68,18 @@ usernamedlg::~usernamedlg() {
 
 void usernamedlg::ok() {
   if (kug->getUsers().lookup(leusername->text()) != NULL) {
-    QMessageBox::information(0, 
-      i18n("Error"), 
+    KMessageBox::error( 0, 
       i18n("User with name %1 already exists.")
-        .arg(leusername->text()), i18n("OK"));
+        .arg(leusername->text()) );
     return;
   }
 
-  if (strlen(leusername->text()) == 0) {
-    QMessageBox::warning(0, i18n("Error"), 
-			 i18n("You have to enter a user name."), 
-			 i18n("OK"));
+  if (leusername->text().isEmpty()) {
+    KMessageBox::error(0, i18n("You have to enter a user name."));
     return;
   }
   
-  user->setFullName(leusername->text());
+  user->setName(leusername->text());
   accept();
 }
 
